#ifndef BINARY_IO_H
#define BINARY_IO_H

#include <iostream>
#include <fstream>
#include <vector>
#include <string>

//using namespace std;

/*
  Matrices are in CRS format: The "dsp" (displacement) vector stores the starting index of each row. So for example
  the third row starts at dsp[2] and ends at (dsp[3] - 1). The "col" vector stores the column indices of each non-zero
  matrix entry. The "ele" vector stores the value af each non-zero matrix entry.
*/


//! \brief A sparse matrix on CRS format (counter, column index, value) is read from a binary file.
//!
//!        The binary file has to store 4 Byte integers and 8 Byte doubles an contains the following data:
//!        - Number of rows
//!        - Number of non-zero elements/blocks
//!        - Number of non-zero matrix elements (= previous number * dofs per block)
//!        - [#elements per row]
//!        - [column indices]
//!        - [matrix elements]
//!
//! \param[in]   file name of binary file
//! \param[out]  cnt  number of non-zero elements per row
//! \param[out]  col  column indices of non-zero elements,  C-Style
//! \param[out]  ele  non-zero elements of matrix
//!
//!

void read_binMatrix(const std::string& file, std::vector<int> &cnt, std::vector<int> &col, std::vector<double> &ele);

//! \brief A sparse matrix on CRS format (counter, column index, value) is read from a binary file.
//!
//!        The binary file has to store 4 Byte integers and 8 Byte doubles an contains the following data:
//!        - Number of rows
//!        - Number of non-zero elements
//!        - Number of non-zero elements
//!        - [#elements per row]
//!        - [column indices]
//!        - [elements]
//!
//! \param[in]   file name of binary file
//! \param[out]  cnt  number of non-zero elements per row
//! \param[out]  col  column indices of non-zero elements,  C-Style
//! \param[out]  ele  non-zero elements of matrix
//!
//!
void write_binMatrix(const std::string& file, const std::vector<int> &cnt, const std::vector<int> &col, const std::vector<double> &ele);


#endif
